
Changelog
=========

0.1.1 (2019-11-10)
-----------------------------------------

* License harmony: BSD to MIT, update source repository user name forming part of the paths / URLs, brushed off bit rot, publication to pypi.


0.1.0 (2016-09-12)
-----------------------------------------

* First release on PyPI.
